@@ -86,6 +86,11 @@ class OptionError(ConfigError):
         self.name = name
 
 
+class NoSuchConfigOption(OptionError):
+
+    fmt = '{name} does not exist.'
+
+
 class OptionValueError(OptionError):
 
     fmt = '{name}: Value "{value}" is not valid.'
